WriteCache class abstract

Constructors

WriteCache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setBool({required String key, required bool value}) → Future
setDouble({required String key, required double value}) → Future
setInt({required String key, required int value}) → Future
setJson({required String key, required Map<String, dynamic> value}) → Future
setListString({required String key, required List<String> value}) → Future
setString({required String key, required String value}) → Future